==> spread-5.7.0.72-py3-none-any.whl: spread_core/projector/test3.py <==
import asyncio
from asyncio_mqtt import Client
import json

file_path = '/var/project/test.txt'
cycle = {"name": "1", "period": 7, "duration": 30, "startLevel": 10, "triggers": {"4": {"day": 1, "time": "09:00", "level": 10}, "5": {"day": 1, "time": "10:00", "level": 20}, "6": {"day": 1, "time": "11:00", "level": 30}, "7": {"day": 1, "time": "12:00", "level": 40}, "8": {"day": 1, "time": "13:00", "level": 50}, "9": {"day": 2, "time": "09:00", "level": 10}, "10": {"day": 2, "time": "10:00", "level": 20}, "11": {"day": 2, "time": "11:00", "level": 30}, "12": {"day": 2, "time": "12:00", "level": 40}, "13": {"day": 2, "time": "13:00", "level": 50}, "14": {"day": 3, "time": "09:00", "level": 10}, "15": {"day": 3, "time": "10:00", "level": 20}, "16": {"day": 3, "time": "11:00", "level": 30}, "17": {"day": 3, "time": "12:00", "level": 40}, "18": {"day": 3, "time": "13:00", "level": 50}, "19": {"day": 0, "time": "08:00", "level": 90}}}


async def publish(client, data):
    await client.publish('Project/1315/test', json.dumps(data), retain=True)


def save_file(client, message):
    with open(file_path, mode='rb') as file:
        try:
            data = json.load(file)
        except json.JSONDecodeError as ex:
            print(f'JSONEncode load error of topic "{message.topic}". {ex.msg}', ex.doc, ex.pos)

    with open(file_path, mode='w') as file:
        try:
            json.dump(cycle, file,  indent=2)
        except json.JSONDecodeError as ex:
            print(f'JSONEncode save error of topic "{message.topic}". {ex.msg}', ex.doc, ex.pos)

    print(message.topic)
    asyncio.create_task(publish(client, data))
    print(message.topic)


async def main():
    async with Client(
            hostname='10.10.1.78',
            port=1883,
            username='admin',
            password='broker',
            client_id='test3'
    ) as client:
        # async with client.filtered_messages('Project/1315/Local/Cycle/1/#') as messages:
        # async with client.filtered_messages('Project/#') as messages:
        async with client.messages() as messages:
            await client.subscribe("Project/+/Ctp")
            print('Subscribe')
            async for message in messages:
                if message.topic.matches('Project/#'):
                    print(message.topic.value)
                    await client.unsubscribe("Project/+/Ctp")
                    print('Unsubscribe')
                # save_file(client, message)


if __name__ == '__main__':
    try:
        asyncio.run(main())
    except KeyboardInterrupt:
        pass

==> spread-5.8.1.80-py3-none-any.whl: spread_core/projector/test3.py <==
import asyncio
from asyncio_mqtt import Client, MqttError
import json

file_path = '/var/project/test.txt'
cycle = {"name": "1", "period": 7, "duration": 30, "startLevel": 10, "triggers": {"4": {"day": 1, "time": "09:00", "level": 10}, "5": {"day": 1, "time": "10:00", "level": 20}, "6": {"day": 1, "time": "11:00", "level": 30}, "7": {"day": 1, "time": "12:00", "level": 40}, "8": {"day": 1, "time": "13:00", "level": 50}, "9": {"day": 2, "time": "09:00", "level": 10}, "10": {"day": 2, "time": "10:00", "level": 20}, "11": {"day": 2, "time": "11:00", "level": 30}, "12": {"day": 2, "time": "12:00", "level": 40}, "13": {"day": 2, "time": "13:00", "level": 50}, "14": {"day": 3, "time": "09:00", "level": 10}, "15": {"day": 3, "time": "10:00", "level": 20}, "16": {"day": 3, "time": "11:00", "level": 30}, "17": {"day": 3, "time": "12:00", "level": 40}, "18": {"day": 3, "time": "13:00", "level": 50}, "19": {"day": 0, "time": "08:00", "level": 90}}}


async def publish(client, data):
    await client.publish('Project/1315/test', json.dumps(data), retain=True)


def save_file(client, message):
    with open(file_path, mode='rb') as file:
        try:
            data = json.load(file)
        except json.JSONDecodeError as ex:
            print(f'JSONEncode load error of topic "{message.topic}". {ex.msg}', ex.doc, ex.pos)

    with open(file_path, mode='w') as file:
        try:
            json.dump(cycle, file,  indent=2)
        except json.JSONDecodeError as ex:
            print(f'JSONEncode save error of topic "{message.topic}". {ex.msg}', ex.doc, ex.pos)

    print(message.topic)
    asyncio.create_task(publish(client, data))
    print(message.topic)


async def main():
    while True:
        print('Service started')
        try:
            async with Client(
                    hostname='10.10.1.77',
                    port=1883,
                    username='admin',
                    password='broker',
                    client_id='test3'
            ) as client:
                async with client.messages() as messages:
                    async for message in messages:
                        if message.topic.matches('Project/#'):
                            print(message.topic.value)
                            await client.unsubscribe("Project/+/Ctp")
                            print('Unsubscribe')
                        save_file(client, message)

        except MqttError as error:
            print(error)
            await asyncio.sleep(3)


if __name__ == '__main__':
    try:
        asyncio.run(main())
    except KeyboardInterrupt:
        print('Service breaked')
